"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.ma_bots2.country2_label_bot import c_1_1_lab

fast_data_c_1_1_lab = [
    {"separator": " by ", "cone_1": "american football teams", "output": "فرق كرة قدم أمريكية"},
    {"separator": " by ", "cone_1": "american rock musicians", "output": "موسيقيو روك أمريكيون"},
    {"separator": " by ", "cone_1": "amphibious warfare vessels", "output": "سفن حربية برمائية"},
    {"separator": " by ", "cone_1": "animated television series", "output": "مسلسلات تلفزيونية رسوم متحركة"},
    {"separator": " by ", "cone_1": "anime and manga", "output": "أنمي ومانغا"},
    {"separator": " by ", "cone_1": "australian open tennis", "output": "بطولة أستراليا المفتوحة للتنس"},
    {"separator": " by ", "cone_1": "australian rules football clubs", "output": "أندية كرة قدم أسترالية"},
    {"separator": " by ", "cone_1": "australian rules football", "output": "كرة القدم الأسترالية"},
    {"separator": " by ", "cone_1": "buildings and structures demolished", "output": "مبان ومنشآت هدمت"},
    {"separator": " by ", "cone_1": "buildings and structures", "output": "مبان ومنشآت"},
    {"separator": " by ", "cone_1": "canadian football teams", "output": "فرق كرة قدم كندية"},
    {"separator": " by ", "cone_1": "christian buildings and structures", "output": "مبان ومنشآت مسيحية"},
    {"separator": " by ", "cone_1": "christian music albums", "output": "ألبومات موسيقى مسيحية"},
    {"separator": " by ", "cone_1": "christian universities and colleges", "output": "جامعات وكليات مسيحية"},
    {"separator": " by ", "cone_1": "dance music albums", "output": "ألبومات موسيقى الرقص"},
    {"separator": " by ", "cone_1": "death metal albums", "output": "ألبومات ديث ميتال"},
    {"separator": " by ", "cone_1": "east german people", "output": "ألمانيون شرقيون"},
    {"separator": " by ", "cone_1": "east german sports-people", "output": "رياضيون ألمانيون شرقيون"},
    {"separator": " by ", "cone_1": "eastern orthodox cathedrals", "output": "كاتدرائيات أرثوذكسية شرقية"},
    {"separator": " by ", "cone_1": "english male actors", "output": "ممثلون ذكور إنجليز"},
    {"separator": " by ", "cone_1": "folk rock albums", "output": "ألبومات فولك روك"},
    {"separator": " by ", "cone_1": "hardcore punk albums", "output": "ألبومات هاردكور بانك"},
    {"separator": " by ", "cone_1": "heavy metal albums", "output": "ألبومات هيفي ميتال"},
    {"separator": " by ", "cone_1": "ice hockey leagues", "output": "دوريات هوكي جليد"},
    {"separator": " by ", "cone_1": "ice hockey teams", "output": "فرق هوكي على الجليد"},
    {"separator": " by ", "cone_1": "indie pop albums", "output": "ألبومات إيندي بوب"},
    {"separator": " by ", "cone_1": "indie rock albums", "output": "ألبومات إيندي روك"},
    {"separator": " by ", "cone_1": "international baseball competitions", "output": "منافسات كرة قاعدة دولية"},
    {"separator": " by ", "cone_1": "latin music albums", "output": "ألبومات موسيقى لاتينية"},
    {"separator": " by ", "cone_1": "law enforcement operations", "output": "عمليات تطبيق القانون"},
    {"separator": " by ", "cone_1": "major league baseball players", "output": "لاعبو دوري كرة القاعدة الرئيسي"},
    {"separator": " by ", "cone_1": "noise music albums", "output": "ألبومات موسيقى نويز"},
    {"separator": " by ", "cone_1": "olympic games bids", "output": "عروض الألعاب الأوليمبية"},
    {"separator": " by ", "cone_1": "palestinian people imprisoned", "output": "فلسطينيون مسجونون"},
    {"separator": " by ", "cone_1": "pop punk albums", "output": "ألبومات بوب بانك"},
    {"separator": " by ", "cone_1": "ports and harbours", "output": "مرافئ وموانئ"},
    {"separator": " by ", "cone_1": "prisoners sentenced to death", "output": "سجناء حكم عليهم بالإعدام"},
    {
        "separator": " by ",
        "cone_1": "prisoners sentenced to life imprisonment",
        "output": "سجناء حكم عليهم بالحبس المؤبد",
    },
    {"separator": " by ", "cone_1": "protestant religious leaders", "output": "قادة دينيون بروتستانتيون"},
    {"separator": " by ", "cone_1": "psychedelic music albums", "output": "ألبومات موسيقى سايكيديلية"},
    {"separator": " by ", "cone_1": "roman catholic archbishops", "output": "رؤساء أساقفة رومان كاثوليك"},
    {"separator": " by ", "cone_1": "roman catholic bishops", "output": "أساقفة كاثوليك رومان"},
    {"separator": " by ", "cone_1": "rugby league coaches", "output": "مدربو دوري رجبي"},
    {"separator": " by ", "cone_1": "science fiction films", "output": "أفلام خيال علمي"},
    {"separator": " by ", "cone_1": "science fiction novels", "output": "روايات خيال علمي"},
    {"separator": " by ", "cone_1": "serbian basketball players", "output": "لاعبو كرة سلة صرب"},
    {"separator": " by ", "cone_1": "sierra leonean people", "output": "سيراليونيون"},
    {"separator": " by ", "cone_1": "south african people", "output": "جنوب إفريقيون"},
    {"separator": " by ", "cone_1": "spoken word albums", "output": "ألبومات كلمة منطوقة"},
    {"separator": " by ", "cone_1": "television series produced", "output": "مسلسلات تلفزيونية أنتجت"},
    {"separator": " by ", "cone_1": "television shows produced", "output": "عروض تلفزيونية أنتجت"},
    {"separator": " by ", "cone_1": "united arab emirates", "output": "الإمارات العربية المتحدة"},
    {"separator": " by ", "cone_1": "united kingdom", "output": "المملكة المتحدة"},
    {"separator": " by ", "cone_1": "united states", "output": "الولايات المتحدة"},
    {
        "separator": " by ",
        "cone_1": "u.s. national championships tennis",
        "output": "البطولات الوطنية الأمريكية لكرة المضرب",
    },
    {"separator": " by ", "cone_1": "united arab emirates", "output": "الإمارات العربية المتحدة"},
    {"separator": " by ", "cone_1": "us open tennis", "output": "بطولة أمريكا المفتوحة للتنس"},
    {"separator": " by ", "cone_1": "world heritage sites", "output": "مواقع التراث العالمي"},
    {"separator": " from ", "cone_1": "australian rules footballers", "output": "لاعبو كرة قدم أسترالية"},
    {"separator": " from ", "cone_1": "field hockey people", "output": "أعلام هوكي ميدان"},
    {"separator": " from ", "cone_1": "field hockey players", "output": "لاعبو هوكي ميدان"},
    {"separator": " from ", "cone_1": "ice hockey people", "output": "أعلام هوكي جليد"},
    {"separator": " from ", "cone_1": "male voice actors", "output": "ممثلو أداء صوتي ذكور"},
    {"separator": " from ", "cone_1": "rugby league players", "output": "لاعبو دوري رجبي"},
    {"separator": " from ", "cone_1": "rugby union players", "output": "لاعبو اتحاد رجبي"},
    {"separator": " from ", "cone_1": "united states house-of-representatives", "output": "مجلس النواب الأمريكي"},
    {"separator": " from ", "cone_1": "water polo players", "output": "لاعبو كرة ماء"},
    {"separator": " in ", "cone_1": "universities and colleges", "output": "جامعات وكليات"},
    {"separator": " in ", "cone_1": "video games set", "output": "ألعاب فيديو تقع أحداثها"},
    {"separator": " in ", "cone_1": "world heritage sites", "output": "مواقع التراث العالمي"},
    {"separator": " of ", "cone_1": "archaeological sites of", "output": "مواقع أثرية في"},
    {"separator": " of ", "cone_1": "battles and operations of", "output": "معارك وعمليات"},
    {"separator": " of ", "cone_1": "burial sites of", "output": "مواقع دفن"},
    {"separator": " of ", "cone_1": "canyons and gorges of", "output": "أخاديد في"},
    {"separator": " of ", "cone_1": "chemical technology of", "output": "تقانة كيميائية في"},
    {"separator": " of ", "cone_1": "chief justices of", "output": "رؤساء قضاء"},
    {"separator": " of ", "cone_1": "congressional districts of", "output": "مقاطعات الكونغرس في"},
    {"separator": " of ", "cone_1": "cultural depictions of", "output": "تصوير ثقافي عن"},
    {"separator": " of ", "cone_1": "drainage basins of", "output": "أحواض تصريف في"},
    {"separator": " of ", "cone_1": "eastern front of", "output": "الجبهة الشرقية في"},
    {"separator": " of ", "cone_1": "featured pictures of", "output": "صور مميزة عن"},
    {"separator": " of ", "cone_1": "fictional depictions of", "output": "تصوير خيالي عن"},
    {"separator": " of ", "cone_1": "government ministers of", "output": "وزراء"},
    {"separator": " of ", "cone_1": "governors general of", "output": "حكام عموم"},
    {"separator": " of ", "cone_1": "indigenous peoples of", "output": "شعوب أصلية في"},
    {"separator": " of ", "cone_1": "lieutenant governors of", "output": "نواب حكام"},
    {"separator": " of ", "cone_1": "mass murder of", "output": "قتل جماعي في"},
    {"separator": " of ", "cone_1": "military operations of", "output": "عمليات عسكرية في"},
    {"separator": " of ", "cone_1": "mountain passes of", "output": "ممرات جبلية في"},
    {"separator": " of ", "cone_1": "mountain ranges of", "output": "سلاسل جبلية في"},
    {"separator": " of ", "cone_1": "mountains and hills of", "output": "جبال وتلال"},
    {"separator": " of ", "cone_1": "national parks of", "output": "متنزهات وطنية في"},
    {"separator": " of ", "cone_1": "national sports teams of", "output": "منتخبات رياضية وطنية في"},
    {"separator": " of ", "cone_1": "native birds of", "output": "طيور محلية في"},
    {"separator": " of ", "cone_1": "naval battles of", "output": "معارك بحرية"},
    {"separator": " of ", "cone_1": "peace treaties of", "output": "معاهدات سلام"},
    {"separator": " of ", "cone_1": "ports and harbours of", "output": "مرافئ وموانئ"},
    {"separator": " of ", "cone_1": "prime ministers of", "output": "رؤساء وزراء"},
    {"separator": " of ", "cone_1": "prisoners and detainees of", "output": "سجناء ومعتقلون في"},
    {"separator": " of ", "cone_1": "protected areas of", "output": "مناطق محمية في"},
    {"separator": " of ", "cone_1": "rock formations of", "output": "تكوينات صخرية في"},
    {"separator": " of ", "cone_1": "sports organizations of", "output": "منظمات رياضية في"},
    {"separator": " of ", "cone_1": "state constitutional officers of", "output": "مسؤولون دستوريون في"},
    {"separator": " of ", "cone_1": "order of", "output": "وسام"},
    {"separator": " of ", "cone_1": "uninhabited islands of", "output": "جزر غير مأهولة في"},
    {"separator": " of ", "cone_1": "vice presidents of", "output": "نواب رؤساء"},
    {"separator": " on ", "cone_1": "art museums and galleries", "output": "متاحف فنية ومعارض"},
    {"separator": " on ", "cone_1": "buildings and structures", "output": "مبان ومنشآت"},
    {"separator": " on ", "cone_1": "demolished buildings and structures", "output": "مبان ومنشآت مهدمة"},
    {"separator": " on ", "cone_1": "disused railway stations", "output": "محطات سكك حديدية مهجورة"},
    {"separator": " on ", "cone_1": "major league baseball", "output": "دوري كرة القاعدة الرئيسي"},
    {"separator": " on ", "cone_1": "military units and formations", "output": "وحدات وتشكيلات عسكرية"},
    {"separator": " on ", "cone_1": "pakistani people imprisoned", "output": "باكستانيون مسجونون"},
    {"separator": " on ", "cone_1": "parks and open spaces", "output": "متنزهات ومساحات مفتوحة"},
    {"separator": " on ", "cone_1": "roman catholic churches", "output": "كنائس رومانية كاثوليكية"},
    {"separator": " on ", "cone_1": "sierra leonean judges", "output": "قضاة سيراليونيون"},
    {"separator": " on ", "cone_1": "south african judges", "output": "قضاة جنوب إفريقيون"},
    {"separator": " on ", "cone_1": "television series set", "output": "مسلسلات تلفزيونية تقع أحداثها"},
    {"separator": " on ", "cone_1": "united states capitol", "output": "كابيتول الولايات المتحدة"},
    {"separator": " on ", "cone_1": "video games set", "output": "ألعاب فيديو تقع أحداثها"},
    {"separator": " to ", "cone_1": "monuments and memorials", "output": "معالم أثرية ونصب تذكارية"},
    {"separator": " to ", "cone_1": "united states navy", "output": "البحرية الأمريكية"},
    {"separator": "-of ", "cone_1": "cabinet secretaries of", "output": "أعضاء مجلس وزراء"},
    {"separator": "-of ", "cone_1": "state cabinet secretaries of", "output": "أعضاء مجلس وزراء"},
]


@pytest.mark.parametrize("data", fast_data_c_1_1_lab, ids=lambda x: x["cone_1"])
@pytest.mark.fast
def test_c_1_1_lab(data) -> None:
    label = c_1_1_lab(data["separator"], data["cone_1"], with_years=False)
    assert label == data["output"]



"""

"""

from typing import Tuple

from ..helps import dump_data, logger


# @dump_data(1)
def list_of_cat_func_new(category_r: str, category_lab: str, list_of_cat: str) -> str:
    """Format category labels using list templates tweaks."""
    category_lab_or = category_lab
    list_of_cat_x = list_of_cat.split("{}")[0].strip()

    logger.info(f"<<lightblue>> list_of_cat_func_new {category_lab=}, {list_of_cat=}, {list_of_cat_x=}")

    if not category_lab.startswith(list_of_cat_x) or list_of_cat_x == "":
        category_lab = list_of_cat.format(category_lab)

    logger.info(f"<<lightblue>> list_of_cat_func_new add {category_lab=}, {category_lab_or=}, {category_r=} ")

    return category_lab


# @dump_data(1)
def list_of_cat_func_foot_ballers(category_r: str, category_lab: str, list_of_cat: str) -> str:
    """
    Format category labels using list templates and football-specific tweaks.

    {"category_r": "guernsey footballers", "category_lab": "غيرنزي", "list_of_cat": "لاعبو {}", "output": "لاعبو  كرة قدم غيرنزي"}
    """
    category_lab_or = category_lab
    list_of_cat_x = list_of_cat.split("{}")[0].strip()

    logger.info(f"<<lightblue>> list_of_cat_func_foot_ballers {category_lab=}, {list_of_cat=}, {list_of_cat_x=}")

    if not category_lab.startswith(list_of_cat_x):
        category_lab = list_of_cat.format(category_lab)

    logger.info(f"<<lightblue>> list_of_cat_func_foot_ballers add {category_lab=}, {category_lab_or=}, {category_r=} ")
    # fix tab[Category:Guernsey footballers] = "تصنيف:لاعبو غيرنزي"

    if "كرة" not in category_lab:
        list_of_cat = list_of_cat.replace("{}", " كرة قدم {}")
        category_lab = list_of_cat.format(category_lab_or)
        logger.info(f"<<lightblue>> list_of_cat_func_foot_ballers add {list_of_cat=}, {category_lab=}, {category_r=} ")

    return category_lab


def list_of_cat_func(category_r: str, category_lab: str, list_of_cat: str, foot_ballers: bool) -> Tuple[str, str]:
    """Format category labels using list templates and football-specific tweaks."""
    category_lab_or = category_lab
    list_of_cat_x = list_of_cat.split("{}")[0].strip()

    logger.info(f"<<lightblue>> list_of_cat_func {category_lab=}, {list_of_cat=}, {list_of_cat_x=}")

    if not category_lab.startswith(list_of_cat_x):
        category_lab = list_of_cat.format(category_lab)

    logger.info(f"<<lightblue>> list_of_cat_func add {category_lab=}, {category_lab_or=}, {category_r=} ")
    # fix tab[Category:Guernsey footballers] = "تصنيف:لاعبو غيرنزي"

    if foot_ballers and "كرة" not in category_lab:
        list_of_cat = list_of_cat.replace("{}", " كرة قدم {}")
        category_lab = list_of_cat.format(category_lab_or)
        logger.info(f"<<lightblue>> list_of_cat_func add {list_of_cat=}, {category_lab=}, {category_r=} ")

    return category_lab, list_of_cat



#!/usr/bin/python3
""" """

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import find_teams_bot, wrap_team_xo_normal_2025_with_ends

test_find_teams_bot_data_0 = {}

test_find_teams_bot_data = {
    "acrobatic gymnastics junior world championships": "بطولة العالم للجمباز الاكروباتيكي للناشئين",
    "acrobatic gymnastics world championships": "بطولة العالم للجمباز الاكروباتيكي",
    "amateur handball world cup": "كأس العالم لكرة اليد للهواة",
    "basketball junior world championships": "بطولة العالم لكرة السلة للناشئين",
    "beach volleyball world championships": "بطولة العالم لكرة الطائرة الشاطئية",
    "cross-country skiing world championships": "بطولة العالم للتزلج الريفي",
    "goalball world championships": "بطولة العالم لكرة الهدف",
    "international basketball council": "المجلس الدولي لكرة السلة",
    "international cricket council": "المجلس الدولي للكريكت",
    "international snowboarding council": "المجلس الدولي للتزلج على الثلوج",
    "international volleyball council": "المجلس الدولي لكرة الطائرة",
    "international handball council": "المجلس الدولي لكرة اليد",
    "men's softball world championship": "بطولة العالم للكرة اللينة للرجال",
    "men's handball championship": "بطولة لكرة اليد للرجال",
    "men's handball world championship": "بطولة العالم لكرة اليد للرجال",
    "men's handball world cup": "كأس العالم لكرة اليد للرجال",
    "motocross world championship": "بطولة العالم للموتو كروس",
    "outdoor world handball championship": "بطولة العالم لكرة اليد في الهواء الطلق",
    "racquetball world championships": "بطولة العالم لكرة الراح",
    "rhythmic gymnastics world championships": "بطولة العالم للجمباز الإيقاعي",
    "rugby world junior championship": "بطولة العالم للرجبي للناشئين",
    "sailing world championship": "بطولة العالم للإبحار",
    "sailing world championships": "بطولة العالم للإبحار",
    "wheelchair basketball world championships": "بطولة العالم لكرة السلة على الكراسي المتحركة",
    "wheelchair handball world championship": "بطولة العالم لكرة اليد على الكراسي المتحركة",
    "women's basketball world championships": "بطولة العالم لكرة السلة للسيدات",
    "women's world wheelchair basketball championship": "بطولة العالم لكرة السلة على الكراسي المتحركة للسيدات",
    "women's world handball championship": "بطولة العالم لكرة اليد للسيدات",
    "women's handball championship": "بطولة لكرة اليد للسيدات",
    "women's handball world championship": "بطولة العالم لكرة اليد للسيدات",
    "women's handball world cup": "كأس العالم لكرة اليد للسيدات",
    "world amateur boxing championships": "بطولة العالم للبوكسينغ للهواة",
    "world amateur handball championship": "بطولة العالم لكرة اليد للهواة",
    "world aquatics championships competitors": "منافسو بطولة العالم للرياضات المائية",
    "world archery championships": "بطولة العالم للنبالة",
    "world athletics championships ": "بطولة العالم لألعاب القوى",
    "world athletics championships medalists": "فائزون بميداليات بطولة العالم لألعاب القوى",
    "world athletics championships": "بطولة العالم لألعاب القوى",
    "world boxing championships": "بطولة العالم للبوكسينغ",
    "world champion national handball teams": "أبطال بطولة العالم لكرة اليد",
    "world fencing championships medalists": "فائزون بميداليات بطولة العالم لمبارزة سيف الشيش",
    "world figure skating championships medalists": "فائزون بميداليات بطولة العالم للتزلج الفني",
    "world handball junior championship": "بطولة العالم لكرة اليد للناشئين",
    "world junior basketball championships": "بطولة العالم لكرة السلة للناشئين",
    "world junior ice hockey championships": "بطولة العالم لهوكي الجليد للناشئين",
    "world junior rugby championships": "بطولة العالم للرجبي للناشئين",
    "world junior short track speed skating championships": "بطولة العالم للتزلج على مسار قصير للناشئين",
    "world junior squash championships": "بطولة العالم للاسكواش للناشئين",
    "world junior wrestling championships": "بطولة العالم للمصارعة للناشئين",
    "world junior handball championship": "بطولة العالم لكرة اليد للناشئين",
    "world netball championship": "بطولة العالم لكرة الشبكة",
    "world netball championships": "بطولة العالم لكرة الشبكة",
    "world outdoor bowls championship": "بطولة العالم للبولينج في الهواء الطلق",
    "world outdoor handball championship": "بطولة العالم لكرة اليد في الهواء الطلق",
    "world rowing championships medalists": "فائزون بميداليات بطولة العالم للتجديف",
    "world skateboarding championship medalists": "فائزون بميداليات بطولة العالم للتزلج على اللوح",
    "world taekwondo championships": "بطولة العالم للتايكوندو",
    "world wheelchair curling championship": "بطولة العالم للكيرلنغ على الكراسي المتحركة",
    "world wheelchair rugby championships": "بطولة العالم للرجبي على الكراسي المتحركة",
    "world wheelchair handball championship": "بطولة العالم لكرة اليد على الكراسي المتحركة",
    "world wrestling championships": "بطولة العالم للمصارعة",
    "world handball amateur championship": "بطولة العالم لكرة اليد للهواة",
    "world handball championship competitors": "منافسو بطولة العالم لكرة اليد",
    "world handball championship medalists": "فائزون بميداليات بطولة العالم لكرة اليد",
    "world handball championship": "بطولة العالم لكرة اليد",
    "world handball youth championship": "بطولة العالم لكرة اليد للشباب",
    "world youth handball championship": "بطولة العالم لكرة اليد للشباب",
    "handball amateur world championship": "بطولة العالم لكرة اليد للهواة",
    "handball junior world championship": "بطولة العالم لكرة اليد للناشئين",
    "handball world amateur championship": "بطولة العالم لكرة اليد للهواة",
    "handball world championship": "بطولة العالم لكرة اليد",
    "handball world cup": "كأس العالم لكرة اليد",
    "handball world junior championship": "بطولة العالم لكرة اليد للناشئين",
    "handball world youth championship": "بطولة العالم لكرة اليد للشباب",
    "handball youth world championship": "بطولة العالم لكرة اليد للشباب",
    "youth handball world cup": "كأس العالم لكرة اليد للشباب",
}


def wrap_callback(category: str) -> str:
    return wrap_team_xo_normal_2025_with_ends(category, callback=find_teams_bot)


@pytest.mark.parametrize("category, expected", test_find_teams_bot_data.items(), ids=test_find_teams_bot_data.keys())
@pytest.mark.fast
def test_Get_New_team_xo_data(category: str, expected: str) -> None:
    label1 = wrap_callback(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize(
    "category, expected", test_find_teams_bot_data_0.items(), ids=test_find_teams_bot_data_0.keys()
)
@pytest.mark.fast
def test_test_find_teams_bot_data_0(category: str, expected: str) -> None:
    label1 = wrap_callback(category)
    assert isinstance(label1, str)
    assert label1 == expected


TEMPORAL_CASES = [
    ("test_find_teams_bot", test_find_teams_bot_data, wrap_callback),
    # ("test_find_teams_bot_with_additional", test_find_teams_bot_data_with_additional, wrap_callback),
]


@pytest.mark.parametrize("name,data,callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""Integration tests for format_multi_data  """

import pytest

from ArWikiCats.translations_formats import FormatDataV2, MultiDataFormatterBaseV2


@pytest.fixture
def multi_bot() -> MultiDataFormatterBaseV2:
    nationality_data = {
        "Afghan": {"male": "أفغاني", "males": "أفغان"},
        "yemeni": {"male": "يمني", "males": "يمنيون"},
        "british": {"male": "بريطاني", "males": "بريطانيون"},
        "american": {"male": "أمريكي", "males": "أمريكيون"},
        "egyptian": {"male": "مصري", "males": "مصريون"},
        "Algerian": {"male": "جزائري", "males": "جزائريون"},
        "Moroccan": {"male": "مغربي", "males": "مغاربة"},
    }

    formatted_data = {
        "{nat1_en} people": "{nat1_men}",  # أمريكيون أفغان
        "{nat1_en} people of jewish descent": "{nat1_men} من أصل يهودي",  # أمريكيون من أصل يهودي
        "{nat1_en} {nat2_en}": "{nat1_men} {nat2_men}",  # أمريكيون أفغان
        "{nat2_en} {nat1_en}": "{nat2_men} {nat1_men}",  # أفغان أمريكيون
        "{nat1_en} people of {nat2_en} descent": "{nat1_men} من أصل {nat2_man}",  # أفغان من أصل أمريكي
        "{nat1_en} people of {nat2_en} jewish descent": "{nat1_men} من أصل يهودي {nat2_man}",
        "{nat1_en} people of {nat2_en}-jewish descent": "{nat1_men} من أصل يهودي {nat2_man}",
    }

    nationality_data_1 = {x: {"nat1_man": v["male"], "nat1_men": v["males"]} for x, v in nationality_data.items()}
    nationality_data_2 = {x: {"nat2_man": v["male"], "nat2_men": v["males"]} for x, v in nationality_data.items()}

    country_bot = FormatDataV2(
        formatted_data=formatted_data,
        data_list=nationality_data_1,
        key_placeholder="{nat1_en}",
    )

    other_bot = FormatDataV2(
        {},
        nationality_data_2,
        key_placeholder="{nat2_en}",
    )

    return MultiDataFormatterBaseV2(
        country_bot=country_bot,
        other_bot=other_bot,
    )


test_first_data = {
    "Afghan people": "أفغان",
    "Algerian people of Jewish descent": "جزائريون من أصل يهودي",
}


@pytest.mark.parametrize("category, expected", test_first_data.items(), ids=test_first_data.keys())
@pytest.mark.fast
def test_first_bot(multi_bot: MultiDataFormatterBaseV2, category: str, expected: str) -> None:
    result = multi_bot.country_bot.search(category)
    assert result == expected


test_match_key_data = {
    "Afghan American": "أفغان أمريكيون",
    "Afghan people of American descent": "أفغان من أصل أمريكي",
    "American people of Afghan descent": "أمريكيون من أصل أفغاني",
    "Algerian people of Moroccan Jewish descent": "جزائريون من أصل يهودي مغربي",
    "Algerian people of Moroccan-Jewish descent": "جزائريون من أصل يهودي مغربي",
}


@pytest.mark.parametrize("category, expected", test_match_key_data.items(), ids=test_match_key_data.keys())
@pytest.mark.fast
def test_standers(multi_bot: MultiDataFormatterBaseV2, category: str, expected: str) -> None:
    result = multi_bot.search_all(category)
    assert result == expected



"""
Tests
"""

from ArWikiCats.legacy_bots.make_bots.bot_2018 import (
    Add_to_pop_All_18,
    get_pop_All_18,
)


def test_add_to_pop_all_18() -> None:
    # Test with an empty dict
    Add_to_pop_All_18({})

    # Test with a sample dictionary
    test_dict = {"key1": "value1", "key2": "value2"}
    Add_to_pop_All_18(test_dict)

    # This function modifies internal state, so we just verify it runs without error
    assert True


def test_get_pop_all_18() -> None:
    # Test with a basic key (likely won't find the key but should return default)
    result = get_pop_All_18("test_key", "default")
    assert isinstance(result, str)

    # Test with empty key and default
    result_empty = get_pop_All_18("", "")
    assert isinstance(result_empty, str)

    # Test with just a key
    result_simple = get_pop_All_18("test_key")
    assert isinstance(result_simple, str)



"""
Static translations used for tennis and tournament related keys.
"""

from ...helps import len_print

TENNIS_KEYS: dict[str, str] = {
    "european athletics championships": "بطولة أوروبا لألعاب القوى",
    "deaflympics": "ديفلمبياد",
    "badminton in the summer olympics": "تنس الريشة في الألعاب الأولمبية الصيفية",
    "asian athletics championships": "بطولة آسيا لألعاب القوى",
    "racewalking": "سباق المشي",
    "european athletics indoor championships": "بطولة أوروبا لألعاب القوى داخل الصالات",
    "european championships": "بطولات أوروبا",
    "swiss cup": "كأس سويسرا لكرة القدم",
    "world championships-in-athletics athletes": "عداؤو بطولة العالم لألعاب القوى",
    "world championships in athletics athletes": "عداؤو بطولة العالم لألعاب القوى",
    "world championships in athletics": "بطولة العالم لألعاب القوى",
    "world championships-in-athletics": "بطولة العالم لألعاب القوى",
    "dutch tt": "كأس هولندا السياحية",
    "world table tennis championships": "بطولات عالمية لتنس الطاولة",
    "world touring car championship": "بطولة العالم لسيارات السياحة",
    "gcc champions league": "كأس الخليج للأندية",
    "german formula three championship": "بطولة فورمولا 3 الألمانية",
    "800 metres": "800 متر",
    "world champions": "أبطال العالم",
    "world championships": "بطولات العالم",
    "association football leagues": "دوريات كرة قدم",
    "figure skating in the winter universiade": "التزلج الفني في الألعاب الجامعية الشتوية",
    "copa argentina": "كوبا أرجنتينا",
    "golf tournaments": "بطولات غولف",
    "cycle racing": "سباق دراجات",
    "cycling competitions": "مسابقات الدراجات",
    "motorcycle racing": "سباق الدراجات النارية",
    "motorcycle racing series": "سلسلة سباقات الدراجات النارية",
    "horse races": "سباقات الخيل",
    "national championships": "بطولات وطنية",
    "rowing competitions": "منافسات تجديف",
    "arab athletics championships": "البطولة العربية لألعاب القوى",
    "badminton in the 2016 summer olympics": "كرة الريشة في الألعاب الأولمبية الصيفية 2016",
    "sports in the summer olympics": "رياضات في الألعاب الأولمبية الصيفية",
    "ice hockey tournaments": "منافسات هوكي للجليد",
    "ligue 1": "الدوري الفرنسي الدرجة الأولى",
    "world baseball classic": "عالم البيسبول الكلاسيكي",
    "international association football competitions": "منافسات كرة قدم دولية",
    "formula e": "فورمولا إي",
    "formula one": "فورمولا ون",
    "portuguese grand prix": "جائزة البرتغال الكبرى",
    "six nations championship": "بطولة الأمم الستة",
    "combination events": "مزيج أحداث",
    "auto racing": "سباق سيارات",
    "auto racing series": "سلسة سباق سيارات",
    "brd năstase țiriac trophy": "بطولة بوخارست للتنس",
    "brisbane international": "بطولة برزبين للتنس",
    "chennai open": "بطولة تشيناي المفتوحة للتنس",
    "australian open (tennis)": "بطولة أستراليا المفتوحة للتنس",
    "barcelona open (tennis)": "بطولة برشلونة للتنس",
    "canadian open (tennis)": "بطولة كندا للأساتذة",
    "chile open (tennis)": "بطولة تشيلي للتنس",
    "china open (tennis)": "بطولة الصين المفتوحة",
    "italian open (tennis)": "روما للماسترز",
    "madrid open (tennis)": "مدريد للماسترز",
    "mexican open (tennis)": "بطولة أكابولكو للتنس",
    "miami open (tennis)": "ميامي للماسترز",
    "qatar open (tennis)": "بطولة قطر المفتوحة للتنس",
    "shanghai masters (tennis)": "شنغهاي للماسترز",
    "australian open tennis": "بطولة أستراليا المفتوحة للتنس",
    "barcelona open tennis": "بطولة برشلونة للتنس",
    "canadian open tennis": "بطولة كندا للأساتذة",
    "chile open tennis": "بطولة تشيلي للتنس",
    "china open tennis": "بطولة الصين المفتوحة",
    "italian open tennis": "روما للماسترز",
    "madrid open tennis": "مدريد للماسترز",
    "mexican open tennis": "بطولة أكابولكو للتنس",
    "miami open tennis": "ميامي للماسترز",
    "qatar open tennis": "بطولة قطر المفتوحة للتنس",
    "shanghai masters tennis": "شنغهاي للماسترز",
    "cincinnati masters": "سنسيناتي للماسترز",
    "citi open": "بطولة واشنطن المفتوحة",
    "davis cup": "كأس ديفيز",
    "delray beach international tennis championships": "بطولة دلراي بيتش الدولية للتنس",
    "dubai tennis championships": "بطولة دبي للتنس",
    "fed cups": "كأس فيد",
    "fed cup": "كأس فيد",
    "french open": "دورة رولان غاروس الدولية",
    "geneva open": "بطولة جنيف المفتوحة",
    "gerry weber open": "بطولة هالي المفتوحة",
    "grand prix hassan ii": "بطولة الدار البيضاء للتنس",
    "hopman cup": "كأس هوبمان",
    "indian wells masters": "إنديان ويلز للماسترز",
    "istanbul open": "بطولة إسطنبول المفتوحة",
    "kremlin cup": "كأس الكرملين",
    "monte-carlo masters": "مونتي كارلو للماسترز",
    "nottingham open": "بطولة نوتنغهام المفتوحة",
    "open sud de france": "بطولة مونبلييه المفتوحة للتنس",
    "open de nice côte d'azur": "بطولة نيس المفتوحة للتنس",
    "paris masters": "باريس للماسترز",
    "portugal open": "البرتغال المفتوحة",
    "rai open": "راي المفتوحة",
    "rio open": "بطولة ريو للتنس",
    "rosmalen grass court championships": "بطولة روزمالين العشبية للتنس",
    "seoul open": "سول المفتوحة",
    "stockholm open": "بطولة ستوكهولم المفتوحة للتنس",
    "stuttgart open": "بطولة شتوتغارت المفتوحة",
    "swedish open": "بطولة السويد المفتوحة للتنس",
    "swiss indoors": "بطولة بازل للتنس",
    "sydney international": "بطولة سيدني للتنس",
    "tennis napoli cup": "كأس نابولي لكرة المضرب",
    "the championships, wimbledon": "بطولة ويمبلدون",
    "tunis open": "دورة تونس المفتوحة للتنس",
    "u.s. men's clay court championships": "بطولة هيوستن للتنس",
    "u.s. national indoor tennis championships": "بطولة ممفيس المفتوحة للتنس",
    "valencia open": "بطولة فالنسيا المفتوحة",
    "world tennis championship": "بطولة مبادلة العالمية للتنس",
    "zagreb indoors": "بطولة زغرب للتنس",
    "itf women's world tennis tour": "الجولة العالمية لتنس السيدات",
}

__all__ = ["TENNIS_KEYS"]

len_print.data_len(
    "tennis.py",
    {
        "TENNIS_KEYS": TENNIS_KEYS,
    },
)



#
import pytest

from ArWikiCats import resolve_arabic_category_label

data2 = {
    "Category:People from Westchester County, New York by _place_holder_": "",
    "Category:People from Westchester county, New York by hamlet": "تصنيف:أشخاص من مقاطعة ويستتشستر (نيويورك) حسب القرية",
    "Category:People from New York": "تصنيف:أشخاص من نيويورك",
    "Category:People from Westchester County, New York": "تصنيف:أشخاص من مقاطعة ويستتشستر (نيويورك)",
    "Category:People from Westchester County, New York by city": "تصنيف:أشخاص من مقاطعة ويستتشستر (نيويورك) حسب المدينة",
    "Category:People from Westchester County, New York by town": "تصنيف:أشخاص من مقاطعة ويستتشستر (نيويورك) حسب البلدة",
    "Category:People from Westchester County, New York by village": "تصنيف:أشخاص من مقاطعة ويستتشستر (نيويورك) حسب القرية",
}


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
@pytest.mark.unit
def test_people_labels_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected



"""Helpers for printing the current process memory usage."""

import importlib.util
import os
import sys


def _resident_memory_bytes() -> int:
    """Return the resident set size for the current process in bytes."""
    if importlib.util.find_spec("psutil") is not None:
        import psutil  # type: ignore

        return psutil.Process(os.getpid()).memory_info().rss

    import resource

    usage = resource.getrusage(resource.RUSAGE_SELF).ru_maxrss
    if sys.platform == "darwin":
        return usage
    return usage * 1024


def print_memory() -> None:
    """Print the current process memory usage to stdout."""
    yellow, purple = "\033[93m%s\033[00m", "\033[95m%s\033[00m"

    usage_mb = _resident_memory_bytes() / (1024 * 1024)

    print(yellow % "Memory usage:", purple % f"{usage_mb:.0f} MB")
